"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.simpleReporter = exports.standardReporter = void 0;
const cli_color_1 = __importDefault(require("cli-color"));
// @ts-ignore
const eastasianwidth_1 = __importDefault(require("eastasianwidth"));
const strip_ansi_1 = __importDefault(require("strip-ansi"));
const eaw = eastasianwidth_1.default;
const loggerError = cli_color_1.default.red;
const loggerWarning = cli_color_1.default.xterm(208);
const markuplint = `markup${cli_color_1.default.xterm(39)('lint')}`;
async function standardReporter(data) {
    const sizes = {
        line: 0,
        col: 0,
        meg: 0,
    };
    for (const result of data.results) {
        sizes.line = Math.max(sizes.line, result.line.toString(10).length);
        sizes.col = Math.max(sizes.col, result.col.toString(10).length);
        sizes.meg = Math.max(sizes.meg, w(result.message));
    }
    const out = [];
    if (data.results.length) {
        const lines = data.sourceCode.split(/\r?\n/g);
        for (const result of data.results) {
            const prev = lines[result.line - 2] || '';
            const line = lines[result.line - 1] || '';
            const next = lines[result.line - 0] || '';
            const before = line.substring(0, result.col - 1);
            const after = line.substring(result.col - 1 + result.raw.length);
            const logger = result.severity === 'error' ? loggerError : loggerWarning;
            out.push(`<${markuplint}> ${logger(`${result.severity}: ${result.message} (${result.ruleId}) ${cli_color_1.default.underline(`${data.filePath}:${result.line}:${result.col}`)}`)}`);
            if (result.line - 1 > 0) {
                out.push(`  ${cli_color_1.default.cyan(p(result.line - 1, sizes.col, true))}: ${space(prev)}`);
            }
            out.push(`  ${cli_color_1.default.cyan(p(result.line, sizes.col, true))}: ${space(before)}${cli_color_1.default.bgRed(result.raw)}${space(after)}`);
            if (!data.color) {
                out.push(`         ${invisibleSpace(before)}${'^'.repeat(result.raw.length)}${invisibleSpace(after)}`);
            }
            out.push(`  ${cli_color_1.default.cyan(p(result.line + 1, sizes.col, true))}: ${space(next)}`);
        }
    }
    else if (!data.problemOnly) {
        if (data.verbose) {
            out.push(`<${markuplint}> ${cli_color_1.default.green('passed')}🎉`);
            out.push(`  Filepath: ${data.filePath}`);
            out.push(`  Parser: ${data.parser}`);
            out.push('  Config: [');
            out.push(`    ${data.configSet.files.join('\n    ')}`);
            out.push('  ]');
            // out.push(JSON.stringify(data, null, 2));
        }
        else {
            out.push(`<${markuplint}> ${cli_color_1.default.green('passed')} ${cli_color_1.default.underline(data.filePath)}`);
        }
    }
    if (!data.noStdOut && out.length) {
        const outs = `${out.join('\n')}\n`;
        process.stdout.write(data.color ? outs : strip_ansi_1.default(outs));
    }
    return data.color ? out : out.map(strip_ansi_1.default);
}
exports.standardReporter = standardReporter;
async function simpleReporter(data) {
    const sizes = {
        line: 0,
        col: 0,
        meg: 0,
    };
    for (const result of data.results) {
        sizes.line = Math.max(sizes.line, result.line.toString(10).length);
        sizes.col = Math.max(sizes.col, result.col.toString(10).length);
        sizes.meg = Math.max(sizes.meg, w(result.message));
    }
    const out = [];
    if (data.results.length) {
        out.push(`<${markuplint}> ${cli_color_1.default.underline(data.filePath)}: ${cli_color_1.default.red('✗')}`);
        for (const result of data.results) {
            const s = result.severity === 'error' ? '❌' : '⚠️';
            out.push(`  ${cli_color_1.default.cyan(`${p(result.line, sizes.line, true)}:${p(result.col, sizes.col)}`)} ${s}  ${p(result.message, sizes.meg)} ${cli_color_1.default.xterm(8)(result.ruleId)} `);
        }
    }
    else if (!data.problemOnly) {
        out.push(`<${markuplint}> ${cli_color_1.default.underline(data.filePath)}: ${cli_color_1.default.green('✓')}`);
    }
    if (!data.noStdOut && out.length) {
        const outs = `${out.join('\n')}\n`;
        process.stdout.write(data.color ? outs : strip_ansi_1.default(outs));
    }
    return data.color ? out : out.map(strip_ansi_1.default);
}
exports.simpleReporter = simpleReporter;
function p(s, pad, start = false) {
    const l = w(`${s}`.trim());
    const d = pad - l;
    const _ = ' '.repeat(d < 0 ? 0 : d);
    return start ? `${_}${s}` : `${s}${_}`;
}
function w(s) {
    return s.replace(/./g, _ => '0'.repeat(eaw.characterLength(_))).length;
}
function space(str) {
    return str
        .replace(/\s+/g, $0 => {
        return cli_color_1.default.xterm(8)($0);
    })
        .replace(/ /g, $0 => '•')
        .replace(/\t/g, $0 => '→   ');
}
function invisibleSpace(str) {
    return str.replace(/\t/g, $0 => '    ').replace(/./g, $0 => ' ');
}
